@@ -8,7 +8,7 @@
 /**
 \mainpage
 
-TikiWiki
+Tikiwiki
 
 DOCUMENTATION
 
@@ -23,7 +23,7 @@ DOCUMENTATION
   come and help if you can and wish.
 
 * Notes about the releases are accessible from http://tikiwiki.org/ReleaseProcess19
-* TikiWiki is also a live community on irc.freenode.net channel #tikiwiki
+* Tikiwiki is also a live community on irc.freenode.net channel #tikiwiki
 
 
 INSTALLATION
@@ -34,7 +34,7 @@ INSTALLATION
 
 COPYRIGHT
 
-Copyright (c) 2002-2005, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.All
+Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.All
 Rights Reserved. See copyright.txt for details and a complete list of authors.
 Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
 
