@@ -116,9 +116,10 @@ class Comments extends TikiLib {
 	return $this->getOne("select count(*) from `tiki_forum_reads` where `user`=? and `threadId`=?",array($user,$threadId));
     }
 
-    function add_thread_attachment( $forum_info, $threadId, $fp = '', $data = '', $name, $type, $size, $inbound_mail = 0 )
+    function add_thread_attachment( $forum_info, $threadId, $fp = '', $data = '', $name, $type, $size, $inbound_mail = 0, $qId = 0 )
     {
 	global $smarty;
+	global $tiki_p_admin_forum, $tiki_p_forum_attach;
 
 	// Deal with attachment
 	if( $forum_info['att'] == 'att_all'
@@ -172,7 +173,7 @@ class Comments extends TikiLib {
 		die;
 	    }
 
-	    return $this->attach_file($threadId, 0, $name, $type, $size, $data,
+	    return $this->attach_file($threadId, $qId, $name, $type, $size, $data,
 		    $fhash, $forum_info['att_store_dir'], $_REQUEST['forumId']);
 	/* attachment */
 	} else {
@@ -596,7 +597,7 @@ class Comments extends TikiLib {
 
 	$result = $this->query($query,array((int) $qId));
 	$res = $result->fetchRow();
-	$res['attchments'] = $this->get_thread_attachments(0, $res['qId']);
+	$res['attachments'] = $this->get_thread_attachments(0, $res['qId']);
 	return $res;
     }
 
@@ -620,9 +621,13 @@ class Comments extends TikiLib {
 		$info['type'],
 		$info['summary'], $info['topic_smiley']
 		);
+    if ($threadId) {
+		$query = "update `tiki_forum_attachments` set `threadId`=$threadId, `qId`=0 where `qId`=$qId";
+		$this->query($query);
+	}
 	$this->remove_queued($qId);
 
-	/* This all looks redundant to me -dheltzel
+	/* This all looks redundant to me -dheltzel (not completely redundant - nkoth - added above)
 	   if ($threadId) {
 	   $query = "update `tiki_forum_attachments` set `threadId`=$threadId where `qId`=$qId";
 
@@ -891,6 +896,14 @@ class Comments extends TikiLib {
 	$this->remove_object("forum", $forumId);
 	$query = "delete from `tiki_forum_attachments` where `forumId`=?";
 	$this->query($query, array((int) $forumId ) );
+	$query = "delete from `tiki_forums_queue` where `forumId`=?";
+	$this->query($query, array((int) $forumId ) );
+	$query = "delete from `tiki_forum_reads` where `forumId`=?";
+	$this->query($query, array((int) $forumId ) );
+	$query = "delete from `tiki_user_watches` where `event`=? and `object`=?";
+	$this->query($query,array('forum_post_topic', $forumId));	
+	$query = "delete from `tiki_user_watches` where `event`=? and `url` like ?";
+	$this->query($query,array('forum_post_thread', '%forumId='.$forumId.'%'));
 	return true;
     }
 
@@ -1094,6 +1107,9 @@ class Comments extends TikiLib {
 
     function register_remove_post($forumId, $parentId) {
 	$this->forum_prune($forumId);
+	$nb = 1; //TODO: needs to count all the posts depending on this post
+	$query = 'update `tiki_forums` set `comments`=`comments`- ?, `threads`=`threads`-1 where `forumId`=?';
+	$result = $this->query($query, array((int)$nb, (int)$forumId));
     }
 
     function forum_add_hit($forumId) {
@@ -1246,8 +1262,13 @@ class Comments extends TikiLib {
 
     function count_comments($objectId) {
 	$object = explode( ":", $objectId, 2);
-	$query = "select count(*) from `tiki_comments` where `objectType`=? and `object`=?";
-	$cant = $this->getOne($query, $object );
+	if ($object[0] == 'topic') {
+		$query = 'select count(*) from `tiki_comments` where `objectType`=? and `parentId`=?';
+		$cant = $this->getOne($query, array('forum', $object[1]));
+	} else {
+		$query = 'select count(*) from `tiki_comments` where `objectType`=? and `object`=?';
+		$cant = $this->getOne($query, $object );
+	}
 	return $cant;
     }
 
@@ -1848,7 +1869,12 @@ class Comments extends TikiLib {
 			$summary, $smiley, $_SERVER["REMOTE_ADDR"],
 			$message_id, $in_reply_to)
 		    );
-	}
+	} else {
+			global $smarty;
+			$smarty->assign('msg', tra("Another post with the same title and content already exists"));
+			$smarty->display("error.tpl");
+			die;
+	}	
 
 	$threadId = $this->getOne("select `threadId` from
 		`tiki_comments` where `hash`=?", array( $hash ) );
@@ -1880,6 +1906,8 @@ class Comments extends TikiLib {
 	$query = "delete from `tiki_forum_attachments` where `threadId`=?";
 	$this->query($query, array( (int) $threadId ) );
 	$this->remove_reported($threadId);
+	$query = "delete from `tiki_user_watches` where `event`=? and `object`=?";
+	$this->query($query,array('forum_post_thread', $threadId));
 	return true;
     }
 
