@@ -1,5 +1,5 @@
 <?php
-// $Header: /cvsroot/tikiwiki/tiki/lib/imagegals/imagegallib.php,v 1.45.2.41 2007/05/02 14:43:04 sylvieg Exp $
+// $Header: /cvsroot/tikiwiki/tiki/lib/imagegals/imagegallib.php,v 1.45.2.42 2007/12/16 17:16:14 luciash Exp $
 
 //this script may only be included - so its better to die if called directly.
 if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
@@ -1050,7 +1050,14 @@ class ImageGalsLib extends TikiLib {
 
 
 	function get_gallery_image($galleryId,$rule='',$sort_mode = '') {
-		$query='select `imageId` from `tiki_images` where `galleryId`=? order by ';
+		$query='select i.`imageId` from `tiki_images` i, `tiki_images_data` d
+                 where i.`imageId`=d.`imageId` and i.`galleryId`=? order by ';
+		/* if sort by filesize while browsing images it needs to be read from tiki_image_data table */
+		if ($sort_mode == 'filesize_asc' || $sort_mode == 'filesize_desc') {
+			$query.='d.';
+		} else {
+			$query.='i.';
+		}
 		$bindvars=array($galleryId);
 		switch($rule) {
 			case 'firstu':
