@@ -358,7 +358,7 @@ class UsersLib extends TikiLib {
 			// see if we can create a new account
 			if ($pam_create_tiki) {
 			    // need to make this better! *********************************************************
-			    $result = $this->add_user($user, $pass, '');
+			    $result = $this->add_user($user, $pass, '', '');
 
 			    // if it worked ok, just log in
 			    if ($result == USER_VALID)
@@ -419,7 +419,7 @@ class UsersLib extends TikiLib {
 			    $randompass = $this->genPass();
 			    // in case CAS auth is turned off accidentally;
 			    // we don't want ppl to be able to login as any user with blank passwords
-			    $result = $this->add_user($user, $randompass, '');
+			    $result = $this->add_user($user, $randompass, '', '');
 
 			    // if it worked ok, just log in
 			    if ($result == USER_VALID)
@@ -502,7 +502,7 @@ class UsersLib extends TikiLib {
 		// see if we can create a new account
 		if ($create_tiki) {
 		    // need to make this better! *********************************************************
-		    $result = $this->add_user($user, $pass, '');
+		    $result = $this->add_user($user, $pass, '', '');
 
 		    // if it worked ok, just log in
 		    if ($result == USER_VALID)
@@ -1699,7 +1699,7 @@ function get_included_groups($group) {
 			$cachelib->invalidate('userslist');
     }
 
-    function add_user($user, $pass, $email, $provpass = '', $valid=NULL) {
+    function add_user($user, $pass, $email, $realname, $provpass = '', $valid=NULL) {
 	global $pass_due, $tikilib, $cachelib, $patterns;
 	global $feature_clear_passwords;
 	// Generate a unique hash; this is also done below in set_user_fields()
@@ -1748,6 +1748,12 @@ function get_included_groups($group) {
 	return true;
     }
 
+	function change_user_name($username, $realname) {
+		$query = "update `tiki_user_preferences` set `value`='$realname' where `user`='$username' and `prefName`='realName'";
+		$result = $this->query($query);
+		return true;
+	}
+
     function change_user_email($user, $email, $pass) {
     // Need to change the email-address for notifications, too
 	global $notificationlib; include_once('lib/notifications/notificationlib.php');
@@ -1796,6 +1802,10 @@ function get_included_groups($group) {
         return $this->getOne("select `email` from `users_users` where " . $this->convert_binary(). " `login`=?", array($user));
     }
 
+    function get_user_name($username) {
+        return $this->getOne("select `value` from `tiki_user_preferences` where `user`='$username' and `prefName`='realName'");
+    }
+
     /**
      *  Returns the contact users' email if set and permitted by Admin->Features settings
      */
@@ -2197,7 +2207,7 @@ function get_included_groups($group) {
 		return $ret;									
 	}
 	function send_validation_email($name, $apass, $email, $again='') {
-		global $tikilib, $validateRegistration, $validateUsers, $sender_email, $smarty;
+		global $tikilib, $validateRegistration, $validateUsers, $sender_email, $smarty, $contact_user;
 		$foo = parse_url($_SERVER['REQUEST_URI']);
 		$foo1 = str_replace('tiki-register', 'tiki-login_validate',$foo['path']);
 		$foo1 = str_replace('tiki-remind_password', 'tiki-login_validate',$foo1);
@@ -2213,8 +2223,13 @@ function get_included_groups($group) {
 			$mail_data = $smarty->fetch('mail/moderate_validation_mail.tpl');
 			$mail_subject = $smarty->fetch('mail/moderate_validation_mail_subject.tpl');
 			if ($sender_email == NULL or !$sender_email) {
+				if ($feature_messages != 'y') {
+        				$smarty->assign('msg', tra("The registration mail can't be sent because there is no server email address set, and this feature is disabled").": feature_messages");
+        				return false;
+				}
 				include_once('lib/messu/messulib.php');
 				$messulib->post_message($contact_user, $contact_user, $contact_user, '', $mail_subject, $mail_data, 5);
+				$smarty->assign('msg',$smarty->fetch('mail/user_admin_validation_msg.tpl'));
 			} else {
 				$mail = new TikiMail();
 				$mail->setText($mail_data);
