@@ -345,7 +345,7 @@ function since_last_visit_new($user) {
     require_once('lib/cache/cachelib.php');
     while ($res = $result->fetchRow())
     {
-        if ($userlib->user_has_perm_on_object($user,$res['trackerId'], 'trackers', 'tiki_p_view_trackers')) {
+        if ($userlib->user_has_perm_on_object($user,$res['trackerId'], 'tracker', 'tiki_p_view_trackers')) {
            $ret["items"]["trackers"]["list"][$count]["href"]  = "tiki-view_tracker_item.php?itemId=" . $res["itemId"];
            $ret["items"]["trackers"]["list"][$count]["title"] = $tikilib->get_short_datetime($res["lastModif"]);
 	   
@@ -368,11 +368,17 @@ function since_last_visit_new($user) {
     $ret["items"]["trackers"]["count"] = $count;
   }
 
+  //get the total of itemss
+  $ret["cant"] = 0;
+  foreach ($ret["items"] as $item) {
+	  $ret["cant"] += $item["count"];
+  }
+
   return $ret;
 
 }
 }
-   
+
 $slvn_info = since_last_visit_new($user);
 $smarty->assign('slvn_info', $slvn_info);
 
