@@ -1,6 +1,6 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/tiki-admin.php,v 1.100.2.34 2007/08/06 00:25:39 marclaporte Exp $
+// $Header: /cvsroot/tikiwiki/tiki/tiki-admin.php,v 1.100.2.40 2007/12/22 02:13:40 nkoth Exp $
 
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
@@ -84,11 +84,11 @@ $smarty->assign('home_gallery', $home_gallery);
 $home_file_gallery = $tikilib->get_preference("home_file_gallery", 0);
 $smarty->assign('home_file_gallery', $home_file_gallery);
 
-$crumbs[] = new Breadcrumb('Administration',
-                              'Sections',
+$crumbs[] = new Breadcrumb(tra('Administration'),
+                              tra('Sections'),
                               'tiki-admin.php',
                               'Admin+Home',
-                              'Help on Administration Home');
+                              tra('Help on Administration Home'));
 
 if (isset($_REQUEST["page"])) {
 	$adminPage = $_REQUEST["page"];
@@ -271,6 +271,30 @@ if(isset($admintitle)) {
 
 $smarty->assign_by_ref('tikifeedback', $tikifeedback);
 
+if ($feature_version_checks == 'y') {
+	if ($tiki_needs_upgrade == 'y' && $tiki_release == $tiki_version)	{
+		// need to reset $tiki_needs_upgrade in case new upgrades do not update $tiki_needs_upgrade in prefs
+		$tiki_needs_upgrade = 'n';
+		$tikilib->set_preference('tiki_needs_upgrade', $tiki_needs_upgrade);
+		$smarty->assign('tiki_needs_upgrade', $tiki_needs_upgrade);
+	}
+	if ($tiki_needs_upgrade != 'y' and $tikilib->now > ($tiki_version_last_check + $tiki_version_check_frequency)) {
+		
+		$tikilib->set_preference('tiki_version_last_check',$tikilib->now);
+
+		$tiki_release = $adminlib->get_last_version($tiki_branch);
+		$tikilib->set_preference('tiki_release',$tiki_release);
+		$smarty->assign('tiki_release', $tiki_release);
+
+		if ($tiki_release != $tiki_version) {
+			$tiki_needs_upgrade = 'y';
+			$tikilib->set_preference('tiki_needs_upgrade', $tiki_needs_upgrade);
+			$smarty->assign('tiki_needs_upgrade', $tiki_needs_upgrade);
+		}
+	}
+}
+
+
 // disallow robots to index page:
 $smarty->assign('metatag_robots', 'NOINDEX, NOFOLLOW');
 
