@@ -234,7 +234,10 @@ if (isset($_REQUEST['check_files'])) {
 		8=>'1.9.6',
 		9=>'1.9.7',
 		10=>'1.9.8',
-		11=>'1.9.8.1'
+    11=>'1.9.8.1',
+    12=>'1.9.8.2',
+    13=>'1.9.8.3',
+		14=>'1.9.9'
 	); // all valid versions. Newer versions have a higher array index
   $result=array();
   md5_check_dir(".",$result);
