@@ -1,6 +1,6 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/tiki-adminusers.php,v 1.34.2.35 2007/08/11 13:50:38 marclaporte Exp $
+// $Header: /cvsroot/tikiwiki/tiki/tiki-adminusers.php,v 1.34.2.39 2007/12/10 08:39:27 kerrnel22 Exp $
 
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
@@ -33,13 +33,13 @@ function batchImportUsers() {
 		$smarty->display("error.tpl");
 		die;
 	}
-	if ($fields[0]!="login" && $fields[0]!="password" && $fields[0]!="email" && $fields[0]!="groups") {
+	if ($fields[0]!="login" && $fields[0]!="password" && $fields[0]!="email" && $fields[0]!="realname" && $fields[0]!="groups") {
 		$smarty->assign('msg', tra("The file does not have the required header:")." login, password, email, groups");
 		$smarty->display("error.tpl");
 		die;	
 	}	
-	$data = @fgetcsv($fhandle, 1000);	
 	while (!feof($fhandle)) {
+		$data = fgetcsv($fhandle, 1000);	
 		$temp_max = count($fields);
 		for ($i = 0; $i < $temp_max; $i++) {
 			if ($fields[$i] == "login" && function_exists("mb_detect_encoding") && mb_detect_encoding($data[$i], "ASCII, UTF-8, ISO-8859-1") ==  "ISO-8859-1") {
@@ -48,10 +48,9 @@ function batchImportUsers() {
 			@$ar[$fields[$i]] = $data[$i];
 		}
 		$userrecs[] = $ar;
-		$data = fgetcsv($fhandle, 1000);
 	}
 	fclose ($fhandle);
-	if (!is_array($userrecs)) {
+	if (empty($userrecs) or !is_array($userrecs)) {
 		$smarty->assign('msg', tra("No records were found. Check the file please!"));
 		$smarty->display("error.tpl");
 		die;
@@ -69,12 +68,14 @@ function batchImportUsers() {
 			$discarded[] = discardUser($u, tra("Email is required"));
 		} elseif (!preg_match($patterns['login'],$u['login'])) {
 			$discarded[] = discardUser($u, tra("Login contains invalid characters"));
+		} elseif (!preg_match($patterns['login'],$u['realname'])) {
+			$discarded[] = discardUser($u, tra("Real name contains invalid characters"));
 		} elseif ($userlib->user_exists($u['login'])and (!isset($_REQUEST['overwrite']))) {
 			$discarded[] = discardUser($u, tra("User is duplicated"));
 		} else {
 			if (!$userlib->user_exists($u['login'])) {
-				$userlib->add_user($u['login'], $u['password'], $u['email']);
-				$logslib->add_log('users',sprintf(tra("Created account %s <%s>"),$u["login"], $u["email"]));				
+				$userlib->add_user($u['login'], $u['password'], $u['email'], $u['realname']);
+				$logslib->add_log('users',sprintf(tra("Created account %s <%s> for %s."),$u["login"], $u["email"], $u["realname"]));				
 			}
 
 			$userlib->set_user_fields($u);
@@ -129,9 +130,11 @@ if (isset($_REQUEST["newuser"])) {
 				$tikifeedback[] = array('num'=>1,'mes'=>sprintf(tra("User %s already exists"),$_REQUEST["name"]));
 			} elseif (!preg_match($patterns['login'],$_REQUEST['name'])) {
 				$tikifeedback[] = array('num'=>1,'mes'=>tra("User login contains invalid characters"));
+			} elseif (!preg_match($patterns['login'],$_REQUEST['realname'])) {
+				$tikifeedback[] = array('num'=>1,'mes'=>tra("User's real name contains invalid characters"));
 			} else {
-				if ($userlib->add_user($_REQUEST["name"], $_REQUEST["pass"], $_REQUEST["email"])) {
-					$tikifeedback[] = array('num'=>0,'mes'=>sprintf(tra("New %s created with %s %s."),tra("user"),tra("username"),$_REQUEST["name"]));
+				if ($userlib->add_user($_REQUEST["name"], $_REQUEST["pass"], $_REQUEST["email"], $_REQUEST["realname"])) {
+					$tikifeedback[] = array('num'=>0,'mes'=>sprintf(tra("New %s created with %s %s (%s)."),tra("user"),tra("username"),$_REQUEST["name"], $_REQUEST["realname"]));
 					$cookietab = '1';
 					$_REQUEST['find'] = $_REQUEST["name"];
 				} else {
@@ -296,13 +299,14 @@ $smarty->assign('find', $find);
 
 $users = $userlib->get_users($offset, $numrows, $sort_mode, $find, $initial, true);
 
-if (!empty($group_management_mode) || !empty($set_default_groups_mode)) {
-	$arraylen = count($users['data']);
-	for ($i=0; $i<$arraylen; $i++) {
+$arraylen = count($users['data']);
+for ($i=0; $i<$arraylen; $i++) {
+	if (!empty($group_management_mode) || !empty($set_default_groups_mode)) {
 		if (in_array($users['data'][$i]['user'], $_REQUEST["checked"])) {
 			$users['data'][$i]['checked'] = 'y';
 		}
 	}
+	$users['data'][$i]['realName'] = $userlib->get_user_name($users['data'][$i]['user']);
 }
 
 $smarty->assign_by_ref('users', $users["data"]);
@@ -327,7 +331,8 @@ if (isset($_REQUEST["user"]) and $_REQUEST["user"]) {
 		$_REQUEST["user"] = $userlib->get_user_id($_REQUEST["user"]);
 	}
 	$userinfo = $userlib->get_userid_info($_REQUEST["user"]);
-	if (isset($_POST["edituser"]) and isset($_POST['name']) and isset($_POST['email'])) {
+	$userinfo['realName'] = $userlib->get_user_name($userinfo['login']);
+	if (isset($_POST["edituser"]) and isset($_POST['name']) and isset($_POST['email']) and isset($_POST['realname'])) {
 		//var_dump($_POST);die;
 		if ($_POST['name']) {
 			if ($userinfo['login'] != $_POST['name']) {
@@ -373,6 +378,15 @@ if (isset($_REQUEST["user"]) and $_REQUEST["user"]) {
 				$tikifeedback[] = array('num'=>1,'mes'=>sprintf(tra("Impossible to change %s from %s to %s"),tra("email"),$userinfo['email'],$_POST["email"]));
 			}
 		}
+		if ($userinfo['realName'] != $_POST['realname']) {
+			if ($userlib->change_user_name($userinfo['login'],$_POST['realname'])) {
+				$tikifeedback[] = array('num'=>0,'mes'=>sprintf(tra("%s changed from %s to %s"),tra("real name"),$userinfo['realName'],$_POST["realname"]));
+				$logslib->add_log('adminusers','','changed realName for '.$_POST['name'].' from '.$userinfo['realName'].' to '.$_POST["realname"]);
+				$userinfo['realName'] = $_POST['realname'];
+			} else {
+				$tikifeedback[] = array('num'=>1,'mes'=>sprintf(tra("Impossible to change %s from %s to %s"),tra("real name"),$userinfo['realName'],$_POST["realname"]));
+			}
+		}
 		if ($chlogin) {
 			if (!preg_match($patterns['login'],$_POST['name'])) {
 				$tikifeedback[] = array('num'=>1,'mes'=>tra("Login contains invalid characters"));
