@@ -1,5 +1,5 @@
 <?php
-// CVS: $Id: tiki-download_file.php,v 1.17.2.8 2007/04/25 14:32:54 sylvieg Exp $
+// CVS: $Id: tiki-download_file.php,v 1.17.2.11 2007/10/26 15:31:56 sylvieg Exp $
 // Initialization
 $output_zip = 'n';
 require_once('tiki-setup.php');
@@ -44,10 +44,16 @@ if (isset($_REQUEST["fileId"])) {
 }
 elseif (isset($_REQUEST["galleryId"]) && isset($_REQUEST["name"])) {
 	$info = $tikilib->get_file_by_name($_REQUEST["galleryId"], $_REQUEST["name"]);
+	$_REQUEST["fileId"] = $info['fileId'];
 }
 else {
   die;
 }
+if (!is_array($info)) {
+	$smarty->assign('msg',tra('Incorrect param'));
+	$smarty->display('error.tpl');
+	die;
+}
 
 $fgal_use_db=$tikilib->get_preference('fgal_use_db','y');
 $fgal_use_dir=$tikilib->get_preference('fgal_use_dir','');
@@ -78,7 +84,6 @@ $foo2=str_replace("tiki-browse_image","show_image",$foo["path"]);
 $smarty->assign('url_browse',$tikilib->httpPrefix().$foo1);
 $smarty->assign('url_show',$tikilib->httpPrefix().$foo2);
 
-
 $tikilib->add_file_hit($_REQUEST["fileId"]);
 
 $type=&$info["filetype"];
