@@ -1,12 +1,12 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/tiki-login.php,v 1.29.2.46 2007/10/03 21:33:53 nkoth Exp $
+// $Header: /cvsroot/tikiwiki/tiki/tiki-login.php,v 1.29.2.47 2007/12/10 08:39:27 kerrnel22 Exp $
 
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
 // Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
 
-# $Header: /cvsroot/tikiwiki/tiki/tiki-login.php,v 1.29.2.46 2007/10/03 21:33:53 nkoth Exp $
+# $Header: /cvsroot/tikiwiki/tiki/tiki-login.php,v 1.29.2.47 2007/12/10 08:39:27 kerrnel22 Exp $
 
 // Initialization
 $bypass_siteclose_check = 'y';
@@ -155,7 +155,7 @@ if ($feature_intertiki == 'y' and isset($_REQUEST['intertiki']) and in_array($_R
 		$user_details = unserialize($response_value->scalarval());
 
 		if (!$userlib->user_exists($user)) {
-		    if ($userlib->add_user($user, '', $user_details['info']['email'])) {
+		    if ($userlib->add_user($user, '', $user_details['info']['email'], '')) {
 		    	$userlib->set_user_fields($user_details['info']);
 				} else {
 					$logslib->add_log('login','intertiki : login creation failed');
