@@ -1,6 +1,6 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/tiki-setup.php,v 1.240.2.161 2007/09/12 15:25:47 marclaporte Exp $
+// $Header: /cvsroot/tikiwiki/tiki/tiki-setup.php,v 1.240.2.170 2007/12/22 05:14:33 mose Exp $
 
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
@@ -31,8 +31,10 @@ class TikiSetup extends TikiInit {
     /*!
         Check that everything is set up properly
 
+
         \static
     */
+
     function check($tikidomain='') {
         static $checked;
 
@@ -43,7 +45,7 @@ class TikiSetup extends TikiInit {
         $checked = true;
 
         $errors = '';
-        
+
         if (strpos($_SERVER["SERVER_SOFTWARE"],"IIS")==TRUE){
 		if (array_key_exists('PATH_TRANSLATED', $_SERVER)) {
 			$docroot = dirname($_SERVER['PATH_TRANSLATED']);
@@ -147,48 +149,46 @@ $errors
 							$install_link = '?multi='.urlencode($tikidomain);
 						}
             if (!TikiSetup::isWindows()) {
-                print "You may either chmod the directories above manually to 777, or run one of the sets of commands below.
-<b><a href='tiki-install.php$install_link'>Proceed to the Tiki installer</a></b> after you run the commands below.
+                            print "Your options:
 
-If you cannot become root, and are NOT part of the group $wwwgroup:
-    \$ bash
-    \$ cd $docroot
-    \$ chmod +x setup.sh
-    \$ ./setup.sh yourlogin yourgroup 02777
-    Tip: You can find your group using the command 'id'.
 
-If you cannot become root, but are a member of the group $wwwgroup:
-    \$ bash
-    \$ cd $docroot
-    \$ chmod +x setup.sh
-    \$ ./setup.sh mylogin $wwwgroup</i>
+	1- With FTP access:
+		a) Change the permissions (chmod) of the directories to 777.
+		b) Create any missing directories
+		c) <a href='tiki-install.php$install_link'>Execute the Tiki installer again</a> (Once you have executed these commands, this message will disappear!)
 
-If you can become root:
-    \$ bash
-    \$ cd $docroot
-    \$ chmod +x setup.sh
-    \$ su -c './setup.sh $wwwuser'
+	or
 
+	2- With shell (SSH) access, you can run the command below.
+
+		a) Run setup.sh and follow the instructions:
+			\$ bash
+			\$ cd $docroot
+			\$ chmod +x setup.sh
+			\$ ./setup.sh
+
+		The script will offer you options depending on your server configuration.
+
+		b) <a href='tiki-install.php$install_link'>Execute the Tiki installer again</a> (Once you have executed these commands, this message will disappear!)
+
+
+<hr>
 If you have problems accessing a directory, check the open_basedir entry in
 $PHP_CONFIG_FILE_PATH/php.ini or $httpd_conf.
 
-Once you have executed these commands, this message will disappear!
+<hr>
 
-Note: If you cannot become root, you will not be able to delete certain
-files created by apache, and will need to ask your system administrator
-to delete them for you if needed.
+<a href='http://doc.tikiwiki.org/Installation' target='_blank'>Consult the tikiwiki.org installation guide</a> if you need more help or <a href='http://tikiwiki.org/tiki-forums.php' target='_blank'>visit the forums</a>
 
-<a href='http://tikiwiki.org/InstallTiki' target='_blank'>Consult the tikiwiki.org installation guide</a> if you need more help.
-
-<b><a href='tiki-install.php'>Proceed to the Tiki installer</a></b> if you've completed the steps above.
 </pre></body></html>";
             }
 
             exit;
         }
-		
-	
+
+
     }
+
 }
 
 TikiSetup::prependIncludePath('lib');
@@ -1231,8 +1231,8 @@ $smarty->assign('mods_server', $mods_server);
 $change_password = 'y';
 $smarty->assign('change_password',$change_password);
 
-/* 
- * Site identity initial default settings 
+/*
+ * Site identity initial default settings
  */
 $feature_siteidentity='n';
 $smarty->assign('feature_siteidentity', $feature_siteidentity);
@@ -1246,7 +1246,7 @@ $sitemycode='<div style="text-align: center; padding-top: 10px">
 <span style="font-size:3em; font-weight: bold; vertical-align:bottom">
 {$siteTitle}
 </span>
-</div>'; 
+</div>';
 $sitemycode_publish='n';
 $smarty->assign('feature_sitemycode', $feature_sitemycode);
 $smarty->assign('sitemycode', $sitemycode);
@@ -1291,10 +1291,26 @@ $smarty->assign('feature_sitetitle', $feature_sitetitle);
 $feature_sitedesc='n';
 $smarty->assign('feature_sitedesc', $feature_sitedesc);
 
-/* 
+/*
  * End of Site identity initial default settings
  */
 
+// version checking
+$feature_version_checks ='y';
+$smarty->assign('feature_version_checks', $feature_version_checks);
+
+$tiki_needs_upgrade = 'n';
+$smarty->assign('tiki_needs_upgrade', $tiki_needs_upgrade);
+
+$tiki_version_last_check = 0;
+$smarty->assign('tiki_version_last_check', $tiki_version_last_check);
+
+$tiki_version_check_frequency = '604800';
+$smarty->assign('tiki_version_check_frequency', $tiki_version_check_frequency);
+
+$tiki_release = '0';
+$smarty->assign('tiki_release', $tiki_release);
+
 // intertiki stuff
 $feature_intertiki = 'n';
 $smarty->assign('feature_intertiki', $feature_intertiki);
@@ -1474,8 +1490,8 @@ $interlist = unserialize($interlist);
 if ($feature_polls == 'y' and isset($_REQUEST["pollVote"])) {
 	if ($tiki_p_vote_poll == 'y' && isset($_REQUEST["polls_optionId"])) {
 		if( $feature_poll_anonymous == 'y' || $user ) {
-			if (!isset($polllib) or !is_object($polllib)) { 
-				include_once('lib/polls/polllib_shared.php'); 
+			if (!isset($polllib) or !is_object($polllib)) {
+				include_once('lib/polls/polllib_shared.php');
 			}
 			$polllib->poll_vote($user, $_REQUEST["polls_pollId"], $_REQUEST["polls_optionId"]);
 			// Poll vote must go first, or the new vote will be seen as the previous one.
@@ -1714,11 +1730,18 @@ if (empty($_REQUEST['page'])) {
 }
 $smarty->assign('page', $page);
 
+// Provide user's page to other scripts. Has to go here, otherwise the
+// modules won't see them.
+$userPage = $feature_wiki_userpage_prefix.$user;
+$exist = $tikilib->page_exists($userPage);
+$smarty->assign("userPage", $userPage);
+$smarty->assign("userPage_exists", $exist);
+
 // We include Tiki modules here (any idea why right here ?)
 include_once ("tiki-modules.php");
 
 if ($feature_warn_on_edit == 'y') {
-    
+
     if (strstr($_SERVER['REQUEST_URI'], 'tiki-editpage')) {
     	$current_page = 'tiki-editpage';
     } elseif (strstr($_SERVER['REQUEST_URI'], 'tiki-index')) {
@@ -1853,7 +1876,7 @@ if ($feature_referer_stats == 'y') {
 
 //Check for an update of dynamic vars
 if(isset($tiki_p_edit_dynvar) && $tiki_p_edit_dynvar == 'y') {
-    if(isset($_REQUEST['_dyn_update'])) { 
+    if(isset($_REQUEST['_dyn_update'])) {
         foreach($_REQUEST as $name => $value) {
             if(substr($name,0,4)=='dyn_' and $name!='_dyn_update') {
                 $tikilib->update_dynamic_variable(substr($name,4),$_REQUEST[$name]);
@@ -1866,7 +1889,7 @@ if(isset($tiki_p_edit_dynvar) && $tiki_p_edit_dynvar == 'y') {
 // Stats
 if ($feature_stats == 'y') {
     if ($count_admin_pvs == 'y' || $user != 'admin') {
-				if (!isset($section) or ($section != 'chat' and $section != 'livesupport')) { 
+				if (!isset($section) or ($section != 'chat' and $section != 'livesupport')) {
             $tikilib->add_pageview();
         }
     }
@@ -2026,4 +2049,20 @@ if ($language == 'ar' || $language == 'he' || $language == 'fa') {
 	$feature_bidi='y';
 	$smarty->assign('feature_bidi', $feature_bidi);
 }
-?>
+
+
+// HARDCODED on purpose !
+// this block should be changed at release time.
+// as well as changing http://tikiwiki.org/stable.version
+
+$tiki_version = '1.9.9';
+$tiki_branch = 'stable';
+$tiki_star = 'Sirius';
+$tiki_uses_cvs = is_dir('CVS') ? 'y' : 'n';
+
+$smarty->assign('tiki_version', $tiki_version);
+$smarty->assign('tiki_branch', $tiki_branch);
+$smarty->assign('tiki_star', $tiki_star);
+$smarty->assign('tiki_uses_cvs', $tiki_uses_cvs);
+
+
