@@ -1,6 +1,6 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/tiki-view_tracker_item.php,v 1.69.2.101 2007/08/14 23:59:07 luciash Exp $
+// $Header: /cvsroot/tikiwiki/tiki/tiki-view_tracker_item.php,v 1.69.2.102 2007/12/10 04:28:34 kerrnel22 Exp $
 
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
@@ -233,10 +233,12 @@ foreach($xfields["data"] as $i=>$array) {
 		$mainfield = $i;
 	}
 
-	if ($xfields["data"][$i]['type'] == 's') {
-		$ins_fields["data"][$i] = $xfields["data"][$i];
-		$rateFieldId = $fid;
-		//$fields["data"][$i] = $xfields["data"][$i];
+	if ($xfields["data"][$i]['type'] == 's') {	// Special system variable
+		if ($xfields["data"][$i]['name'] == "Rating") {	// Ratings
+			$ins_fields["data"][$i] = $xfields["data"][$i];
+			$rateFieldId = $fid;
+			//$fields["data"][$i] = $xfields["data"][$i];
+		} // Do nothing for ItemID here.
 	} elseif ($xfields["data"][$i]['isHidden'] != 'y' or $tiki_p_admin_trackers == 'y') {
 		$ins_fields["data"][$i] = $xfields["data"][$i];
 		$fields["data"][$i] = $xfields["data"][$i];
@@ -687,6 +689,15 @@ if(isset($error)) {
 		}
 	}
 }	
+
+// Do ID fills as necessary to support the showID stuff
+if (isset($_REQUEST["itemId"]) && $_REQUEST["itemId"]) {
+	$leadingZeroesId = str_pad($_REQUEST["itemId"], 9, '0', STR_PAD_LEFT);
+	$hyphenatedId = substr($leadingZeroesId, 0, 3) . '-' . substr($leadingZeroesId, 3, 3) . '-' . substr($leadingZeroesId, 6);
+	$smarty->assign('leadingZeroesId', $leadingZeroesId);
+	$smarty->assign('hyphenatedId', $hyphenatedId);
+}
+
 $smarty->assign('trackerId', $_REQUEST["trackerId"]);
 $smarty->assign('tracker_info', $tracker_info);
 $smarty->assign_by_ref('info', $info);
