@@ -1,8 +1,8 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/tiki-webmail.php,v 1.25.2.10 2006/11/02 14:35:46 sylvieg Exp $
+// $Header: /cvsroot/tikiwiki/tiki/tiki-webmail.php,v 1.25.2.16 2007/08/12 18:22:35 mose Exp $
 
-// Copyright (c) 2002-2005, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
+// Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
 // Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
 
@@ -30,7 +30,7 @@ require_once ("lib/webmail/net_pop3.php");
 //require_once ("lib/webmail/mimeDecode.php");
 require_once ("lib/mail/mimelib.php");
 include_once ("lib/webmail/class.rc4crypt.php");
-include_once ("lib/webmail/htmlMimeMail.php");
+include_once ("lib/webmail/tikimaillib.php");
 /*
 function parse_output(&$obj, &$parts, $i) {
 	if (!empty($obj->parts)) {
@@ -150,12 +150,25 @@ if ($_REQUEST["locSection"] == 'read') {
 	if (isset($_REQUEST["delete_one"])) {
 		check_ticket('webmail');
 		$aux = $pop3->getParsedHeaders($_REQUEST["msgdel"]);
+		if (isset($aux["Message-Id"])) {
+			$aux["Message-ID"] = $aux["Message-Id"];
+		} elseif (isset($aux["Message-id"])) {
+			$aux["Message-ID"] = $aux["Message-id"];
+		}
 		$realmsgid = ereg_replace("[<>]","",$aux["Message-ID"]);
 		$webmaillib->remove_webmail_message($current["accountId"], $user, $realmsgid);
 		$pop3->deleteMsg($_REQUEST["msgdel"]);
 	}
 
 	$aux = $pop3->getParsedHeaders($_REQUEST["msgid"]);
+	if (isset($aux["Message-Id"])) {
+		$aux["Message-ID"] = $aux["Message-Id"];
+	} elseif (isset($aux["Message-id"])) {
+		$aux["Message-ID"] = $aux["Message-id"];
+	}
+	if (!isset($aux["Message-ID"])) { 
+		$aux["Message-ID"] = 'unknown';
+	}
 	$message = $pop3->getMsg($_REQUEST["msgid"]);
 	$realmsgid = ereg_replace("[<>]","",$aux["Message-ID"]);
 	$smarty->assign('msgid', $_REQUEST["msgid"]);
@@ -249,6 +262,9 @@ if ($_REQUEST["locSection"] == 'read') {
 
 		$output['header']["replyto"] = $to_addresses;
 	}
+	if (!isset($output['header']["delivery-date"])) {
+		$output['header']['delivery-date'] = $output['header']['date'];
+	}
 	$output['header']['timestamp'] = strtotime($output['header']['delivery-date']);
 	$smarty->assign('headers', $output['header']);
 }
@@ -306,6 +322,11 @@ if ($_REQUEST["locSection"] == 'mailbox') {
 	if (isset($_REQUEST["delete_one"])) {
 		check_ticket('webmail');
 		$aux = $pop3->getParsedHeaders($_REQUEST["msgdel"]);
+		if (isset($aux["Message-Id"])) {
+			$aux["Message-ID"] = $aux["Message-Id"];
+		} elseif (isset($aux["Message-id"])) {
+			$aux["Message-ID"] = $aux["Message-id"];
+		}
 		$realmsgid = ereg_replace("[<>]","",$aux["Message-ID"]);
 		$webmaillib->remove_webmail_message($current["accountId"], $user, $realmsgid);
 		$pop3->deleteMsg($_REQUEST["msgdel"]);
@@ -373,6 +394,14 @@ if ($_REQUEST["locSection"] == 'mailbox') {
 
 		for ($i = 1; $i <= $mailsum; $i++) {
 			$aux = $pop3->getParsedHeaders($i);
+			if (isset($aux["Message-Id"])) {
+				$aux["Message-ID"] = $aux["Message-Id"];
+			} elseif (isset($aux["Message-id"])) {
+				$aux["Message-ID"] = $aux["Message-id"];
+			}
+			if (!isset($aux["Message-ID"])) { 
+				$aux["Message-ID"] = 'unknown'.time();
+			}
 			$aux["subject"] = decode_subject_utf8($aux["Subject"]);
 			$aux["msgid"] = $i;
 			$aux["realmsgid"] = ereg_replace("[<>]","",$aux["Message-ID"]);
@@ -414,7 +443,15 @@ if ($_REQUEST["locSection"] == 'mailbox') {
 			$aux = $filtered[$i];
 		} else {
 			$aux = $pop3->getParsedHeaders($i);
-			preg_match('/<?([-!#$%&\'*+\.\/0-9=?A-Z^_`a-z{|}~]+@[-!#$%&\'*+\/0-9=?A-Z^_`a-z{|}~]+\.[-!#$%&\'*+\.\/0-9=?A-Z^_`a-z{|}~]+)>?/',$aux["From"],$mail);
+			if (isset($aux["Message-Id"])) {
+				$aux["Message-ID"] = $aux["Message-Id"];
+			} elseif (isset($aux["Message-id"])) {
+				$aux["Message-ID"] = $aux["Message-id"];
+			}
+			if (!isset($aux["Message-ID"])) { 
+				$aux["Message-ID"] = 'unknown'.time();
+			}
+			preg_match('/<?([-!#$%&\'*+\.\/0-9=?A-Z^_`a-z{|}~]+@[-!#$%&\'*+\/0-9=?A-Z^_`a-z{|}~]+(\.[-!#$%&\'*+\.\/0-9=?A-Z^_`a-z{|}~]+)?)>?/',$aux["From"],$mail);
 			$aux["sender"]["email"] = $mail[1];
 			$aux["subject"] = decode_subject_utf8($aux["Subject"] );
 			$aux["timestamp"] = strtotime($aux['Date']);
@@ -557,11 +594,16 @@ if ($_REQUEST["locSection"] == 'compose') {
 	$smarty->assign('attaching', 'n');
 
 	if (isset($_REQUEST["send"])) {
-		$mail = new htmlMimeMail();
+		$mail = new TikiMail($user);
 
-		$mail->setFrom($current["account"]);
-		$mail->setCc($_REQUEST["cc"]);
-		$mail->setBcc($_REQUEST["bcc"]);
+		$email = $userlib->get_user_email($user);
+		$mail->setFrom($email);
+		if (!empty($_REQUEST["cc"])) {
+			$mail->setCc($_REQUEST["cc"]);
+		}
+		if (!empty($_REQUEST["bcc"])) {
+			$mail->setBcc($_REQUEST["bcc"]);
+		}
 		$mail->setSubject($_REQUEST["subject"]);
 
 		if ($_REQUEST["attach1"]) {
